gchecky.model.diagnosis_t

Package gchecky :: Module model :: Class diagnosis_t |
[hide private]
[frames] | no frames]

# Class diagnosis_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    diagnosis_t

Represents a diagnostic response to an API request. The diagnostic response contains the parsed XML in your request as well as any warnings generated by your request. Please see the Validating XML Messages to Google Checkout section for more information about diagnostic requests and responses.

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``diagnosis``'`` The document's unique xml tag name.
| input_xml = `Any:PATH(input-xml):REQ`
| warnings = `List:PATH(warnings):OP`...``
| _fields = ``{``'``input_xml``'``:` Any:PATH(input-xml):REQ`,` `'``warnings``'``:` L`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### warnings Value:
      List:PATH(warnings):OPT:[
          String:PATH(string):REQ
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'input_xml': Any:PATH(input-xml):REQ,
       'warnings': List:PATH(warnings):OPT:[
          String:PATH(string):REQ
      ]}